@@ -67,6 +67,13 @@ class App(nested_diff.cli.App):
         """Return parser for optional part (dash prefixed) of CLI args."""
         parser = super().get_optional_args_parser()
 
+        parser.add_argument(
+            '--show',
+            action='store_true',
+            help="don't diff arguments, just format and show them; nested "
+                 'diffs expected on input',
+        )
+
         parser.add_argument(
             '--text-ctx',
             default=3,
@@ -85,6 +92,12 @@ class App(nested_diff.cli.App):
             help='output file; STDOUT is used if omitted',
         )
 
+        parser.add_argument(
+            '-q', '--quiet',
+            action='store_true',
+            help="don't show diff, exit code is the only difference indicator",
+        )
+
         parser.add_argument('-A', type=int, choices=(0, 1), default=1,
                             help='show added items; enabled by default')
         parser.add_argument('-N', type=int, choices=(0, 1), default=1,
@@ -103,8 +116,12 @@ class App(nested_diff.cli.App):
         """Return parser for positional part (files etc) of CLI args."""
         parser = super().get_positional_args_parser()
 
-        parser.add_argument('file1', type=argparse.FileType())
-        parser.add_argument('file2', type=argparse.FileType())
+        parser.add_argument(
+            'files',
+            metavar='file',
+            nargs='+',
+            type=argparse.FileType(),
+        )
 
         return parser
 
@@ -132,16 +149,66 @@ class App(nested_diff.cli.App):
 
     def run(self):
         """Diff app object entry point."""
-        diff = self.diff(
-            self.load(self.args.file1),
-            self.load(self.args.file2),
-        )
-        exit_code = 0 if not diff or 'U' in diff else 1
+        if self.args.show:
+            return self.run_format()
 
-        self.dump(self.args.out, diff, self.args.ofmt)
+        if len(self.args.files) < 2:
+            self.argparser.error('Two or more arguments expected for diff')
+
+        return self.run_diff()
+
+    def run_diff(self):
+        """Compute and print diff."""
+        if len(self.args.files) > 2:
+            if self.args.out.isatty():
+                header_template = '\033[33m--- {a}\n+++ {b}\033[0m\n'
+            else:
+                header_template = '--- {a}\n+++ {b}\n'
+        else:
+            header_template = ''
+
+        a = None
+        exit_code = 0
+
+        for file_ in self.args.files:
+            b = {'name': file_.name, 'data': self.load(file_)}
+
+            if a is not None:
+                diff = self.diff(a['data'], b['data'])
+
+                if diff and 'U' not in diff:
+                    exit_code = 1
+
+                if self.args.quiet:
+                    continue
+
+                header = header_template.format(a=a['name'], b=b['name'])
+                self.dump(self.args.out, diff, self.args.ofmt, header=header)
+
+            a = b
 
         return exit_code
 
+    def run_format(self):
+        """Format and print diff."""
+        if len(self.args.files) > 1:
+            if self.args.out.isatty():
+                header_template = '\033[33m=== {filename}\033[0m\n'
+            else:
+                header_template = '=== {filename}\n'
+        else:
+            header_template = ''
+
+        for file_ in self.args.files:
+            self.dump(
+                self.args.out,
+                self.load(file_),
+                self.args.ofmt,
+                header=header_template.format(filename=file_.name),
+            )
+
+        return 0
+
 
 class AbstractFmtDumper(nested_diff.cli.Dumper):
     """Base class for diff formatters dumpers."""
